#!/usr/bin/gnuplot

DW_Dauphas(M) = exp(3.6*M**2 - 11.08*M + 10.37)

lnDW1(M) = a1*M**2 + b1*M + c1
lnDW2(M) = a2*M**2 + b2*M + c2

set xr [0:0.052]

a1=0.0
b1=11.08
c1=10.37

fit lnDW1(x) "DW.dat" u 1:(log($2)) via b1,c1

print "a1 = ", a1
print "b1 = ", b1
print "c1 = ", c1

set xr [0.046:1]

a2=3.6
b2=11.08
c2=10.37

fit lnDW2(x) "DW.dat" u 1:(log($2)) via a2,b2,c2

print "a2 = ", a2
print "b2 = ", b2
print "c2 = ", c2

# older fit (data from Nicolas Fig.)
#a1 = 0.00
#b1 = 17.33
#c1 = 9.06

#a2 = 3.62
#b2 = -11.15
#c2 = 10.52

########################################################################

set xl "{/Helvetica-Oblique m} [M_E]"
set yl "{/Helvetica-Oblique D}_W"

set xr [0:1]
set yr [5:50000]

set logscale y
set ytics (\
  ""     5e0 1,\
  ""     6e0 1,\
  ""     7e0 1,\
  ""     8e0 1,\
  ""     9e0 1,\
  "10"   1e1 0,\
  ""     2e1 1,\
  ""     3e1 1,\
  ""     4e1 1,\
  ""     5e1 1,\
  ""     6e1 1,\
  ""     7e1 1,\
  ""     8e1 1,\
  ""     9e1 1,\
  "100"  1e2 0,\
  ""     2e2 1,\
  ""     3e2 1,\
  ""     4e2 1,\
  ""     5e2 1,\
  ""     6e2 1,\
  ""     7e2 1,\
  ""     8e2 1,\
  ""     9e2 1,\
  "10^3" 1e3 0,\
  ""     2e3 1,\
  ""     3e3 1,\
  ""     4e3 1,\
  ""     5e3 1,\
  ""     6e3 1,\
  ""     7e3 1,\
  ""     8e3 1,\
  ""     9e3 1,\
  "10^4" 1e4 0,\
  ""     2e4 1,\
  ""     3e4 1,\
  ""     4e4 1,\
  ""     5e4 1,\
  )

set nocolorbox
set palette rgbformulae 33,13,10
set palette gray
set cbr [1:4]
set key spacing 1.5 samplen 1.0 font "Helvetica,14" 
set lmargin 6.6
set rmargin 0.5
set bmargin 3.1
set tmargin 0.2

tmp=0.046; set arrow from tmp,graph 0 to tmp,graph 1 nohead lt 0
tmp=0.052; set arrow from tmp,graph 0 to tmp,graph 1 nohead lt 0

p "DW.dat" u 1:2:3 t "Fischer and Nimmo (2018)" w p lc palette z,\
  exp(lnDW1(x)) t sprintf("{/Helvetica-Oblique D}_W = exp(%.2fm + %.2f)",b1,c1) w l lt 4 lw 2 dt 2,\
  exp(lnDW2(x)) t sprintf("{/Helvetica-Oblique D}_W = exp(%.2fm^2 {\261} %.2fm + %.2f)",a2,abs(b2),c2) w l lt 6 lw 2,\
  31. w l not lt 0

#pa -1

set term post eps enh color solid "Helvetica,18"
set out "DW_fit.eps"
set size 0.8,0.6
rep

q

  "DW.dat_ORIG" u 1:2 w p,\
  DW_Dauphas(x) w l,\


