#!/usr/bin/gnuplot

GM_SI = 1.32712440018e20
AU_SI = 149597870700.0
MSOL_SI = 1.98855e30
SIGMA2CGS = MSOL_SI*1000.0/(AU_SI*100.0)**2

R_STANDARD = 8.3144598
MMW = 2.4
R_SI = R_STANDARD/(MMW*0.001)
T2SI = GM_SI/R_SI/AU_SI

ADIABIND = 1.4
MOLWEIGTH = 1.0
GASCONST = 1.0
SQRT_ADIABIND_INV = 1.0/sqrt(ADIABIND)
SQRT2PI_INV = 1.0/sqrt(2.0*pi)

MSOL_SI = 1.98855e30
RHO2CGS = MSOL_SI*1000.0/(AU_SI*100.0)**3

Omega(r) = r**(-1.5)
cs(T) = sqrt(ADIABIND*T/MOLWEIGTH*GASCONST)
H(r,T) = cs(T)/Omega(r)*SQRT_ADIABIND_INV

rho(r,Sigma,T) = Sigma/H(r,T)*SQRT2PI_INV

T_MRI = 1000
T_evaporation = 1500

########################################################################

AU_SI = 149597870700.0
MSOL_SI = 1.98855e30
OPA2CU = MSOL_SI*1000.0/(AU_SI*100.0)**2

########################################################################

set encoding utf8
set term pdf enh color solid font "DejaVuSans,10" size 6.5cm,2.25cm
set out "profiles_planets3.pdf"
#set size 0.8,0.48

set xl ""
set yl "{/CMMI10 T} {/csr10 [K]}" font "DejaVuSans,12" offset 0.6,0

load "config.plt"

r(i) = Rmin+(Rmax-Rmin)*int(i/Nsec)/Nr
r2(i) = Rmin+(Rmax-Rmin)*int(i/2)/Nr
f(Sigma) = Sigma*SIGMA2CGS
g(T) = T*T2SI

x1=0.0
x2=1.6
set xr [x1:x2]
y1=-200
y2=1800
set yr [y1:y2]
set cbr [0.0:1.2]
set xtics 0.5
set xtics in scale 0.7 format ""
set ytics out 500 scale 0.7 offset 0.5,0 nomirror 
set key at graph 0.95,graph 0.72 spacing 1.2 samplen 3.5 font "DejeVuSans,7"
set grid noxtics noytics front
set nocolorbox

set lmargin 8.4
set rmargin 0.2
set bmargin 0.2
set tmargin 0.2

set style line 1 lt 1 lw 3
set style line 4 lt 4 lc 'blue' lw 2 dt 4

# Pollack etal. (1994); Tab. 3, rho = 1.e-8 or 1.e-6
#
# iron Fe                               1395    1612 K
# olivine (Mg,Fe)_2 SiO_4               1408    1570 K
#   forsterite Mg_2 SiO_4
#   fayalite Fe_2 SiO_4
# orthopyroxene                         1331    1462 K
#   pyroxene XY(Si,Al)_2 O_6
#   (ortho)enstatite Mg_2 Si_2 O_6
#   (ortho)ferrosilite Fe_2 Si_2 O_6
#   (wollastonite) Ca_2 Si_2 O_6
# troilite FeS                           680     680 K

x3=0.37
x4=0.4625
y3=1400
y4=1600

set label "{/=8{/DejaVuSans-Bold T}_{ev}}"  at 0.070,first T_evaporation+10 tc '#000000'
tmp=x3; set arrow from tmp,graph 0 to tmp,graph 1 nohead lw 1.5 lc rgb '#80ff8000' front
tmp=x4; set arrow from tmp,graph 0 to tmp,graph 1 nohead lw 1.5 lc rgb '#80ff8000' front

f_(m) = sqrt(m)*1.2

p \
  "../../5planet_stable_FLUX2e-4/test_relax2/gastemper0120.cfg"      u (r($0)):(g($1))  t "{/Symbol S}_0 = 750 g cm^{-2}, slope -1.5" w l ls 1,\
  "../../5planet_1over10/test_relax2/gastemper0060.cfg"              u (r2($0)):(g($1)) t "{/Symbol S}_0 = 75 g cm^{-2}"              w l ls 4,\
  "box.dat" u (x1+$1*(x2-x1)):(y3+$2*(y4-y3)) w filledcurves not lc rgb '#80ff8000' lw 0,\
  "ss.dat" u 3:(0.0):(f_($6)) not w p lc 'gray'    pt 7 ps var,\
  "ss.dat" u 3:(0.0):(f_($6)) not w p lc '#808080' pt 6 ps var,\
  "<awk '{ print $3*(1-$4); print $3*(1+$4); print s; }' ss.dat" u 1:(0.0) not w l lc '#808080',\

########################################################################

q


