#!/usr/bin/gnuplot

AU_SI = 149597870700.0
cm = 1.e-2

########################################################################

set term post eps enh color dashed "Helvetica" 18
set out "profiles_pebble4.eps"
set size 0.8,0.905

set multiplot
set origin 0,0
set size 0.8,0.50

set xl "{/Helvetica-Oblique r} [au]"
set yl "{/Helvetica-Oblique D}_{p} [cm]" offset -1.0,0

Nr=1024
Nsec=1
Rmin=0.2
Rmax=2.0
r(i) = Rmin+(Rmax-Rmin)*int(i/Nsec)/Nr
f(x) = x*AU_SI/cm

set xr [0.2:2.0]
y1=0
y2=4.5
set yr [y1:y2]
set ytics 1
set zeroaxis
set grid noxtics noytics front
set key at graph 0.75,graph 0.925 spacing 1.2 samplen 1.0 font "Helvetica,14"

set lmargin 7.8
set rmargin 1.5
set bmargin 3.1
set tmargin 0.1

set style line 1 lt 1 lw 5
set style line 2 lt 2 lw 4
set style line 3 lt 3 lw 3
set style line 4 lt 4 lw 2 dt 2
set style line 5 lt 8 lw 1 dt 3
set style line 6 lt 8 lw 1 dt 4
set style line 7 lt 6 lw 1 dt 6

p \
  "box.dat" u (Rmin+$1*(1.2*Rmin-Rmin)):(y1+$2*(y2-y1))   w filledcurves not lc rgb '#cccccc',\
  "box.dat" u (Rmax-$1*(Rmax-0.9*Rmax)):(y1+$2*(10.0-y1)) w filledcurves not lc rgb '#dddddd',\
  "pebblesize0_0.txt" u (r($0)):(f($1))  t "{/Symbol S}_0 = 750 g cm^{-2}, slope -1.5" w l ls 1,\
  "pebblesize0_3.txt" u (r($0)):(f($1))  t "{/Symbol S}_0 = 75 g cm^{-2}"              w l ls 4,\
  "pebblesize0_9.txt" u (r($0)):(f($1))  t "Semenov opacities"                         w l ls 5,\
  "pebblesize0_5.txt" u (r($0)):(f($1))  t "MRI-active"                                w l ls 2,\

#pa -1

########################################################################

set origin 0,0.51
set size 0.8,0.39

set xl ""
set yl "{/Symbol-Oblique t}" offset +2.0,0

f(x) = x

set xtics format ""
y1=0.001
y2=0.30
set yr [y1:y2]
set ytics auto
set logscale y
set nokey
set bmargin 0.1

p \
  "box.dat" u (Rmin+$1*(1.2*Rmin-Rmin)):(y1+$2*(y2-y1)) w filledcurves not lc rgb '#cccccc',\
  "box.dat" u (Rmax-$1*(Rmax-0.9*Rmax)):(y1+$2*(y2-y1)) w filledcurves not lc rgb '#dddddd',\
  "pebblestokes0_0.txt" u (r($0)):(f($1))  t "{/Symbol S}_0 = 750 g cm^{-2}, slope -1.5" w l ls 1,\
  "pebblestokes0_3.txt" u (r($0)):(f($1))  t "{/Symbol S}_0 = 75 g cm^{-2}"              w l ls 4,\
  "pebblestokes0_9.txt" u (r($0)):(f($1))  t "Semenov opacities"                         w l ls 5,\
  "pebblestokes0_5.txt" u (r($0)):(f($1))  t "MRI-active"                                w l ls 2,\


